library(testthat)
library(natmanager)

.libPaths( c( "/home/runner/work/_temp/Library" , .libPaths()))

test_check("natmanager")
